@@ -8,9 +8,9 @@
  * (C) 2009-2010 Doug Engert (deengert@anl.gov)
  * (C) 2010 James Y Knight (foom@fuhm.net)
  * (C) 2010-2013 Ken Dreyer <ktdreyer at ktdreyer.com>
- * (C) 2012-2016 Mark Proehl <mark at mproehl.net>
- * (C) 2012-2016 Olaf Flebbe <of at oflebbe.de>
- * (C) 2013-2016 Daniel Kobras <d.kobras@science-computing.de>
+ * (C) 2012-2017 Mark Proehl <mark at mproehl.net>
+ * (C) 2012-2017 Olaf Flebbe <of at oflebbe.de>
+ * (C) 2013-2017 Daniel Kobras <d.kobras at science-computing.de>
  *
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,9 +35,9 @@
 #include <cctype>
 
 
-std::string create_default_machine_password(const std::string &samaccountname)
+std::string create_default_machine_password(const std::string &sAMAccountName)
 {
-    std::string machine_password(samaccountname);
+    std::string machine_password(sAMAccountName);
 
     /* Default machine password after 'reset account' is created with the
      * following algorithm:
@@ -48,22 +48,24 @@ std::string create_default_machine_password(const std::string &samaccountname)
      *
      */
 
-    // Remove trailing '$'
+    /* Remove trailing '$' */
     if (machine_password[machine_password.size() - 1] == '$') {
         machine_password.resize(machine_password.size() - 1);
     }
 
-    // Truncate to first 14 characters
+    /* Truncate to first 14 characters */
     if (machine_password.size() > MAX_DEF_MACH_PASS_LEN) {
         machine_password.resize(MAX_DEF_MACH_PASS_LEN);
     }
 
-    // Convert all characters to lowercase
+    /* Convert all characters to lowercase */
     for (size_t i = 0; i < machine_password.size(); i++) {
         machine_password[i] = std::tolower(machine_password[i]);
     }
 
-    VERBOSE("Default machine password for %s is %s", samaccountname.c_str(), machine_password.c_str());
+    VERBOSE("Default machine password for %s is %s",
+            sAMAccountName.c_str(),
+            machine_password.c_str());
 
     return machine_password;
 }
@@ -76,17 +78,19 @@ static std::string g_ccache_filename;
 std::string get_tempfile_name(const char *name)
 {
     std::string full_template = sform("%s/%s-XXXXXX", TMP_DIR, name);
-    char template_arr[full_template.size() + 1];
-    memcpy(template_arr, full_template.c_str(), full_template.size() + 1);
+    char *template_arr = strdup(full_template.c_str());
 
     int fd = mkstemp(template_arr);
     if (fd < 0) {
-        throw Exception(sform("Error: mkstemp failed: %d", errno));
+        error_exit("mkstemp failed");
     }
 
-    // Didn't need an fd, just to have the filename created securely.
+    /* Didn't need an fd, just to have the filename created securely. */
     close(fd);
-    return std::string(template_arr);
+    std::string tempfile_name = std::string(template_arr);
+    free(template_arr);
+
+    return tempfile_name;
 }
 
 
@@ -138,18 +142,19 @@ void create_fake_krb5_conf(msktutil_flags *flags)
 #ifdef HAVE_SETENV
     int ret = setenv("KRB5_CONFIG", g_config_filename.c_str(), 1);
     if (ret) {
-        throw Exception("setenv failed");
+        error_exit("setenv failed");
     }
 #else
     int ret = putenv(strdup((std::string("KRB5_CONFIG=") +  g_config_filename).c_str()));
     if (ret) {
-        throw Exception("putenv failed");
+        error_exit("putenv failed");
     }
 #endif
 
     VERBOSE("Created a fake krb5.conf file: %s", g_config_filename.c_str());
 
-    g_context.reload();
+    destroy_g_context();
+    initialize_g_context();
 }
 
 
@@ -175,27 +180,30 @@ void switch_default_ccache(const char *ccache_name)
 {
     VERBOSE("Using the local credential cache: %s", ccache_name);
 
-    // Is this setenv really necessary given krb5_cc_set_default_name?
-    // ...answer: YES, because ldap's sasl won't be using our context object,
-    // and may in fact be using a different implementation of kerberos entirely!
+    /* Is this setenv really necessary given krb5_cc_set_default_name?
+     * ...answer: YES, because ldap's sasl won't be using our context
+     * object, and may in fact be using a different implementation of
+     * kerberos entirely! */
 #ifdef HAVE_SETENV
     if (setenv("KRB5CCNAME", ccache_name, 1)) {
-        throw Exception("Error: setenv failed");
+        error_exit("setenv failed");
     }
 #else
     if (!putenv(strdup((std::string("KRB5CCNAME=")+ ccache_name).c_str()))) {
-        throw Exception("Error: putenv failed");
+        error_exit("putenv failed");
     }
 #endif
-    krb5_cc_set_default_name(g_context.get(), ccache_name);
+    krb5_cc_set_default_name(g_context, ccache_name);
 }
 
 
-bool try_machine_keytab_princ(msktutil_flags *flags, const std::string &principal_name,
+bool try_machine_keytab_princ(msktutil_flags *flags,
+                              const std::string &principal_name,
                               const char *ccache_name)
 {
     try {
-        VERBOSE("Trying to authenticate for %s from local keytab...", principal_name.c_str());
+        VERBOSE("Trying to authenticate for %s from local keytab",
+                principal_name.c_str());
         KRB5Keytab keytab(flags->keytab_readname);
         KRB5Principal principal(principal_name);
         KRB5Creds creds(principal, keytab);
@@ -215,9 +223,12 @@ bool try_machine_keytab_princ(msktutil_flags *flags, const std::string &principa
 bool try_machine_password(msktutil_flags *flags, const char *ccache_name)
 {
     try {
-        VERBOSE("Trying to authenticate for %s with password.", flags->samAccountName.c_str());
-        KRB5Principal principal(flags->samAccountName);
-        KRB5Creds creds(principal, /*password:*/ create_default_machine_password(flags->samAccountName));
+        VERBOSE("Trying to authenticate for %s with password",
+                flags->sAMAccountName.c_str());
+        KRB5Principal principal(flags->sAMAccountName);
+        KRB5Creds creds(principal,
+                        /*password:*/
+                        create_default_machine_password(flags->sAMAccountName));
         KRB5CCache ccache(ccache_name);
         ccache.initialize(principal);
         ccache.store(creds);
@@ -231,11 +242,13 @@ bool try_machine_password(msktutil_flags *flags, const char *ccache_name)
 }
 
 
-bool try_machine_supplied_password(msktutil_flags *flags, const char *ccache_name)
+bool try_machine_supplied_password(msktutil_flags *flags,
+                                   const char *ccache_name)
 {
     try {
-        VERBOSE("Trying to authenticate for %s with supplied password.", flags->samAccountName.c_str());
-        KRB5Principal principal(flags->samAccountName);
+        VERBOSE("Trying to authenticate for %s with supplied password",
+                flags->sAMAccountName.c_str());
+        KRB5Principal principal(flags->sAMAccountName);
         KRB5Creds creds(principal, /*password:*/ flags->old_account_password);
         KRB5CCache ccache(ccache_name);
         ccache.initialize(principal);
@@ -261,7 +274,7 @@ bool get_creds(msktutil_flags *flags)
     g_ccache_filename = get_tempfile_name(".mskt_krb5_ccache");
     std::string ccache_name = "FILE:" + g_ccache_filename;
     try {
-        KRB5Principal principal(flags->samAccountName);
+        KRB5Principal principal(flags->sAMAccountName);
         KRB5Creds creds(principal, /*password:*/ flags->password);
         KRB5CCache ccache(ccache_name.c_str());
         ccache.initialize(principal);
@@ -279,15 +292,16 @@ bool get_creds(msktutil_flags *flags)
 bool try_user_creds()
 {
     try {
-        VERBOSE("Checking if default ticket cache has tickets...");
-        // The following is for the side effect of throwing an exception or not.
+        VERBOSE("Checking if default ticket cache has tickets");
+        /* The following is for the side effect of throwing an
+         * exception or not. */
         KRB5CCache ccache(KRB5CCache::defaultName());
         KRB5Principal princ(ccache);
 
         return true;
     } catch(KRB5Exception &e) {
         VERBOSE("%s", e.what());
-        VERBOSE("User ticket cache was not valid.");
+        VERBOSE("User ticket cache was not valid");
         return false;
     }
 }
@@ -296,39 +310,59 @@ bool try_user_creds()
 int find_working_creds(msktutil_flags *flags)
 {
     /* We try some different ways, in order:
-       1) Use principal from keytab. Try both:
-         a) samAccountName
-         b) host/full-hostname (for compat with older msktutil which didn't write the first).
-       2) Use principal samAccountName with default password (samAccountName_nodollar)
-       3) Use supplied credentials (--old-account-password)
-          When the supplied password has expired (e.g. because the service account
-          has been newly created) we cannot find any working credentials here
-          and have to return AUTH_FROM_SUPPLIED_EXPIRED_PASSWORD.
-          In this case working credentials need to be obtained after changing password
-       4) Calling user's existing credentials from their credential cache.
+     * 1) Use principal from keytab. Try both:
+     *    a) sAMAccountName
+     *    b) host/full-hostname (for compat with older msktutil which
+     *       didn't write the first).
+     * 2) Use principal sAMAccountName with default password
+     *    (sAMAccountName_nodollar)
+     * 3) Use supplied credentials (--old-account-password)
+     *    When the supplied password has expired (e.g. because
+     *    the service account has been newly created) we cannot find
+     *    any working credentials here and have to return
+     *    AUTH_FROM_SUPPLIED_EXPIRED_PASSWORD.
+     *    In this case working credentials need to be obtained
+     *    after changing password
+     * 4) Calling user's existing credentials from their credential
+     *    cache.
     */
-
     if (!flags->user_creds_only) {
         std::string host_princ = "host/" + flags->hostname;
-
-        // NOTE: we have to use an actual file for the credential cache, and not a MEMORY: type,
-        // because libsasl may be using heimdal, while this program may be compiled against MIT
-        // kerberos. So, while it's all in the same process and you'd think an in-mem ccache would
-        // be the right thing, the two kerberos implementations cannot share an in-memory ccache, so
-        // we have to use a file. Sigh.
+        /*
+         * NOTE: we have to use an actual file for the credential
+         * cache, and not a MEMORY: type, because libsasl may be using
+         * heimdal, while this program may be compiled against MIT
+         * kerberos. So, while it's all in the same process and you'd
+         * think an in-mem ccache would be the right thing, the two
+         * kerberos implementations cannot share an in-memory ccache,
+         * so we have to use a file. Sigh.
+         */
         g_ccache_filename = get_tempfile_name(".mskt_krb5_ccache");
         std::string ccache_name = "FILE:" + g_ccache_filename;
 
-        if (!flags->keytab_auth_princ.empty() && try_machine_keytab_princ(flags, flags->keytab_auth_princ, ccache_name.c_str())) {
+        if (!flags->keytab_auth_princ.empty() &&
+            access(flags->keytab_file.c_str(), R_OK) == 0 &&
+            try_machine_keytab_princ(flags,
+                                     flags->keytab_auth_princ,
+                                     ccache_name.c_str())) {
             return AUTH_FROM_EXPLICIT_KEYTAB;
         }
-        if (try_machine_keytab_princ(flags, flags->samAccountName, ccache_name.c_str())) {
+        if (access(flags->keytab_file.c_str(), R_OK) == 0 &&
+            try_machine_keytab_princ(flags,
+                                     flags->sAMAccountName,
+                                     ccache_name.c_str())) {
             return AUTH_FROM_SAM_KEYTAB;
         }
-        if (try_machine_keytab_princ(flags, flags->samAccountName_uppercase, ccache_name.c_str())) {
+        if (access(flags->keytab_file.c_str(), R_OK) == 0 &&
+            try_machine_keytab_princ(flags,
+                                     flags->sAMAccountName_uppercase,
+                                     ccache_name.c_str())) {
             return AUTH_FROM_SAM_UPPERCASE_KEYTAB;
         }
-        if (try_machine_keytab_princ(flags, host_princ, ccache_name.c_str())) {
+        if (access(flags->keytab_file.c_str(), R_OK) == 0 &&
+            try_machine_keytab_princ(flags,
+                                     host_princ,
+                                     ccache_name.c_str())) {
             return AUTH_FROM_HOSTNAME_KEYTAB;
         }
         if (try_machine_password(flags, ccache_name.c_str())) {
