@@ -8,9 +8,9 @@
  * (C) 2009-2010 Doug Engert (deengert@anl.gov)
  * (C) 2010 James Y Knight (foom@fuhm.net)
  * (C) 2010-2013 Ken Dreyer <ktdreyer at ktdreyer.com>
- * (C) 2012-2016 Mark Proehl <mark at mproehl.net>
- * (C) 2012-2016 Olaf Flebbe <of at oflebbe.de>
- * (C) 2013-2016 Daniel Kobras <d.kobras@science-computing.de>
+ * (C) 2012-2017 Mark Proehl <mark at mproehl.net>
+ * (C) 2012-2017 Olaf Flebbe <of at oflebbe.de>
+ * (C) 2013-2017 Daniel Kobras <d.kobras at science-computing.de>
  *
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 #include <time.h>
 #include <limits.h>
 #include <netdb.h>
+#include <netinet/in.h>
 #include <sys/socket.h>
 #include <sys/utsname.h>
 #include <ldap.h>
@@ -92,6 +93,7 @@
 
 /* From SAM.H */
 #define UF_WORKSTATION_TRUST_ACCOUNT    0x00001000
+#define UF_ACCOUNT_DISABLE              0x00000002
 #define UF_NORMAL_ACCOUNT               0x00000200
 #define UF_DONT_EXPIRE_PASSWORD         0x00010000
 #define UF_TRUSTED_FOR_DELEGATION       0x00080000
@@ -103,7 +105,7 @@
 #define MS_KERB_ENCTYPE_DES_CBC_MD5             0x02
 #define MS_KERB_ENCTYPE_RC4_HMAC_MD5            0x04
 
-// Define these if the system supports them, otherwise define to 0.
+/* Define these if the system supports them, otherwise define to 0. */
 #if HAVE_DECL_ENCTYPE_AES128_CTS_HMAC_SHA1_96
 #define MS_KERB_ENCTYPE_AES128_CTC_HMAC_SHA1_96 0x08
 #else
@@ -150,9 +152,11 @@ enum msktutil_mode {
     MODE_AUTO_UPDATE,
     MODE_FLUSH,
     MODE_CLEANUP,
-    MODE_PRECREATE
+    MODE_PRECREATE,
+    MODE_DELETE
 };
 
+
 class msktutil_flags {
 public:
     std::string keytab_file;
@@ -166,13 +170,12 @@ public:
     std::string realm_name;
     std::string lower_realm_name;
     std::string base_dn;
-    std::string samAccountName;
-    std::string samAccountName_nodollar;
-    std::string samAccountName_uppercase;
+    std::string sAMAccountName;
+    std::string sAMAccountName_nodollar;
+    std::string sAMAccountName_uppercase;
     std::string password;
     bool password_from_cmdline;
     std::string userPrincipalName;
-    std::string unicodePwd;
     std::string old_account_password;
     std::string site;
     LDAPConnection* ldap;
@@ -180,15 +183,17 @@ public:
     std::string ad_dnsHostName;
     std::vector<std::string> ad_principals;
 
-    bool set_description;
     bool set_userPrincipalName;
     bool no_reverse_lookups;
     bool no_canonical_name;
     bool server_behind_nat;
     bool set_samba_secret;
     bool check_replication;
+    bool dont_change_password;
 
     msktutil_val dont_expire_password;
+    msktutil_val dont_update_dnshostname;
+    msktutil_val disable_account;
     msktutil_val no_pac;
     msktutil_val delegate;
     unsigned int ad_userAccountControl; /* value AD has now */
@@ -244,20 +249,24 @@ public:
 };
 
 /* Prototypes */
-extern std::string create_default_machine_password(const std::string &samaccountname);
+extern std::string create_default_machine_password(const std::string &sAMAccountName);
 extern void ldap_cleanup(msktutil_flags *);
 extern void init_password(msktutil_flags *);
 extern std::string get_default_hostname(bool no_canonical_name = false);
 extern void get_default_keytab(msktutil_flags *);
+extern std::string get_salt(msktutil_flags *);
 extern void get_default_ou(msktutil_flags *);
 
 extern void ldap_get_base_dn(msktutil_flags *);
 extern std::string complete_hostname(const std::string &,
                                      bool no_canonical_name = false);
+extern std::string get_default_samaccountname(msktutil_flags *);
 extern std::string get_short_hostname(msktutil_flags *);
 extern int flush_keytab(msktutil_flags *);
 extern void cleanup_keytab(msktutil_flags *);
 extern void update_keytab(msktutil_flags *);
+extern void add_keytab_entries(msktutil_flags *);
+extern void remove_keytab_entries(msktutil_flags *,std::vector<std::string>);
 extern void add_principal_keytab(const std::string &, msktutil_flags *);
 extern int ldap_flush_principals(msktutil_flags *);
 extern int set_password(msktutil_flags *);
@@ -268,7 +277,6 @@ extern int ldap_add_principal(const std::string &, msktutil_flags *);
 int ldap_remove_principal(const std::string &principal, msktutil_flags *flags);
 extern std::string get_dc_host(const std::string &realm_name, const std::string &site_name,
                                const bool);
-extern std::string get_user_principal();
 extern std::string get_host_os();
 extern bool ldap_check_account(msktutil_flags *);
 extern void ldap_create_account(msktutil_flags *);
@@ -282,10 +290,13 @@ int generate_new_password(msktutil_flags *flags);
 /* Verbose messages */
 #define VERBOSE(text...) if (g_verbose) { fprintf(stdout, " -- %s: ", __FUNCTION__); fprintf(stdout, ## text); fprintf(stdout, "\n"); }
 
+/* Fatal error */
+void error_exit(const char *text);
 
-#endif
+/* To be used by higher level error messages, like krb5 */
+void v_error_exit(const char* format, ...);
 
-// printf into a C++ string.
+/* printf into a C++ string. */
 std::string sform(const char* format, ...);
 
 class Exception : public std::exception
@@ -293,13 +304,13 @@ class Exception : public std::exception
   protected:
     std::string m_message;
 
-    // Prohibit assignment
+    /* Prohibit assignment */
     Exception& operator=(const Exception&);
 
   public:
-    // Constructors
+    /* Constructors */
 
-    // Default construction with no message uses "Exception"
+    /* Default construction with no message uses "Exception" */
     Exception() : m_message("Exception") { }
     explicit Exception(char const * simple_string) : m_message(simple_string) {}
     explicit Exception(const std::string &str) : m_message(str) {}
@@ -338,6 +349,9 @@ class LDAPException : public Exception
 
 #include "krb5wrap.h"
 #include "ldapconnection.h"
+#include "msktname.h"
 
 
 
+#endif
+
